@@ -31,8 +31,10 @@ from docutils.parsers.rst import directives
 from docutils import nodes, languages
 
 # project imports
-from attowiki import serve_pages
-from attowiki.rstdirective_todo import Todo
+from attowiki import views
+from attowiki.rst_directives import add_node
+from attowiki.rst_directives import todo, visit_todo, depart_todo, Todo
+from attowiki.rst_directives import done, visit_done, depart_done, Done
 from attowiki.tools import attowiki_distro_path
 
 
@@ -48,10 +50,27 @@ def main():
     # add the label
     languages.en.labels["todo"] = "Todo"
     # add node
-    nodes._add_node_class_names(['todo', 'todolist'])
+    add_node(todo,
+             html=(visit_todo, depart_todo),
+             latex=(visit_todo, depart_todo),
+             text=(visit_todo, depart_todo))
+    #nodes._add_node_class_names(['todo'])
+
     # register the new directive todo
     directives.register_directive('todo', Todo)
 
+    # add the label
+    languages.en.labels["done"] = "Done"
+    # add node
+    add_node(done,
+             html=(visit_done, depart_done),
+             latex=(visit_done, depart_done),
+             text=(visit_done, depart_done))
+    #nodes._add_node_class_names(['todo'])
+
+    # register the new directive todo
+    directives.register_directive('done', Done)
+
     # Check if the directory is under git, if not, create the repo
     try:
         Repo()
@@ -66,23 +85,37 @@ def main():
 
     # All the Urls of the project
     # index or __index__
-    app.route('/', method='GET')(serve_pages.view_page)
+    app.route('/', method='GET')(views.view_page)
     # new page
-    app.route('/', method='POST')(serve_pages.view_page)
-    app.route('/edit/')(serve_pages.view_edit)
+    app.route('/', method='POST')(views.view_page)
+    # meta pages
+    app.route('/__index__')(views.view_meta_index)
+    app.route('/__cheatsheet__')(views.view_meta_cheat_sheet)
+    app.route('/__history__/<gitref>/<name>.__source__')(views.view_history_source)
+    app.route('/__history__/<gitref>/<name>.__diff__')(views.view_history_diff)
+    app.route('/__history__/<gitref>/<name>')(views.view_history)
+    app.route('/__<admonition_name>__')(views.view_meta_admonition)
+
+    # new page
+    app.route('/edit/')(views.view_edit)
     # edit an existing page
-    app.route('/edit/<name>')(serve_pages.view_edit)
+    app.route('/edit/<name>')(views.view_edit)
+
     # cancel the edition of an existing page
-    app.route('/cancel-edit/')(serve_pages.view_cancel_edit)
-    app.route('/cancel-edit/<name>')(serve_pages.view_cancel_edit)
-    # render an existing page using docutils
-    app.route('/<name>.__iframe__', method='GET')(serve_pages.view_iframe)
+    app.route('/cancel-edit/')(views.view_cancel_edit)
+    app.route('/cancel-edit/<name>')(views.view_cancel_edit)
+
+    # meta page for one single document
+    app.route('/<name>.__source__')(views.view_history_source)
+    app.route('/<name>.__diff__')(views.view_history_diff)
+    app.route('/<name>.__<admonition_name>__')(views.view_meta_admonition)
     # view an existing page
-    app.route('/<name>', method='GET')(serve_pages.view_page)
+    app.route('/<name>', method='GET')(views.view_page)
+
     # write new content to an existing page
-    app.route('/<name>', method='POST')(serve_pages.view_page)
+    app.route('/<name>', method='POST')(views.view_page)
     # write new content to an existing page (without commit - for quick save)
-    app.route('/<name>', method='PUT')(serve_pages.view_quick_save_page)
+    app.route('/<name>', method='PUT')(views.view_quick_save_page)
 
     # for devt purpose: set bottle in debug mode
     bottle.debug(True)  # this line may be commented in production mode
